==> _private_core_network-0.0.79.tar.gz: lib/network_resources/model/payment_order.dart <==
class PaymentOrder {
  int? id;
  String? uuid;
  String? orderNumber;
  int? price;
  String? countryCode;
  int? createdAt;
  int? vat;
  String? proDisplayName;
  String? proUniqueId;
  String? userDisplayName;
  String? userUniqueId;
  String? paymentStatusLabel;
  int? deliveryAddressId;
  List<OrderItems>? items;
  OrderDeliveryAddress? deliveryAddress;

  PaymentOrder(
      {this.id,
      this.uuid,
      this.orderNumber,
      this.price,
      this.countryCode,
      this.createdAt,
      this.vat,
      this.proDisplayName,
      this.proUniqueId,
      this.userDisplayName,
      this.userUniqueId,
      this.paymentStatusLabel,
      this.deliveryAddressId,
      this.items,
      this.deliveryAddress});

  PaymentOrder.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    uuid = json["uuid"];
    orderNumber = json["orderNumber"];
    price = json["price"];
    countryCode = json["countryCode"];
    createdAt = json["createdAt"];
    vat = json["VAT"];
    proDisplayName = json["proDisplayName"];
    proUniqueId = json["proUniqueId"];
    userDisplayName = json["userDisplayName"];
    userUniqueId = json["userUniqueId"];
    paymentStatusLabel = json["paymentStatusLabel"];
    deliveryAddressId = json["deliveryAddressId"];
    items = json["items"] == null
        ? null
        : (json["items"] as List).map((e) => OrderItems.fromJson(e)).toList();
    deliveryAddress = json["deliveryAddress"] == null
        ? null
        : OrderDeliveryAddress.fromJson(json["deliveryAddress"]);
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["uuid"] = uuid;
    _data["orderNumber"] = orderNumber;
    _data["price"] = price;
    _data["countryCode"] = countryCode;
    _data["createdAt"] = createdAt;
    _data["VAT"] = vat;
    _data["proDisplayName"] = proDisplayName;
    _data["proUniqueId"] = proUniqueId;
    _data["userDisplayName"] = userDisplayName;
    _data["userUniqueId"] = userUniqueId;
    _data["paymentStatusLabel"] = paymentStatusLabel;
    _data["deliveryAddressId"] = deliveryAddressId;
    if (items != null) {
      _data["items"] = items?.map((e) => e.toJson()).toList();
    }
    if (deliveryAddress != null) {
      _data["deliveryAddress"] = deliveryAddress?.toJson();
    }
    return _data;
  }

  PaymentOrder copyWith({
    int? id,
    String? uuid,
    String? orderNumber,
    int? price,
    String? countryCode,
    int? createdAt,
    int? vat,
    String? proDisplayName,
    String? proUniqueId,
    String? userDisplayName,
    String? userUniqueId,
    String? paymentStatusLabel,
    int? deliveryAddressId,
    List<OrderItems>? items,
    OrderDeliveryAddress? deliveryAddress,
  }) =>
      PaymentOrder(
        id: id ?? this.id,
        uuid: uuid ?? this.uuid,
        orderNumber: orderNumber ?? this.orderNumber,
        price: price ?? this.price,
        countryCode: countryCode ?? this.countryCode,
        createdAt: createdAt ?? this.createdAt,
        vat: vat ?? this.vat,
        proDisplayName: proDisplayName ?? this.proDisplayName,
        proUniqueId: proUniqueId ?? this.proUniqueId,
        userDisplayName: userDisplayName ?? this.userDisplayName,
        userUniqueId: userUniqueId ?? this.userUniqueId,
        paymentStatusLabel: paymentStatusLabel ?? this.paymentStatusLabel,
        deliveryAddressId: deliveryAddressId ?? this.deliveryAddressId,
        items: items ?? this.items,
        deliveryAddress: deliveryAddress ?? this.deliveryAddress,
      );
}

class OrderDeliveryAddress {
  String? street1;
  String? street2;
  String? zip;
  String? city;
  String? state;
  String? country;
  String? countryCode;
  String? informations;
  String? phone;
  String? phoneCode;
  int? placeCatId;
  int? oowoo;
  int? lng;
  int? lat;
  String? utcModifier;
  int? frequentationDensity;
  int? roadtype;

  OrderDeliveryAddress(
      {this.street1,
      this.street2,
      this.zip,
      this.city,
      this.state,
      this.country,
      this.countryCode,
      this.informations,
      this.phone,
      this.phoneCode,
      this.placeCatId,
      this.oowoo,
      this.lng,
      this.lat,
      this.utcModifier,
      this.frequentationDensity,
      this.roadtype});

  OrderDeliveryAddress.fromJson(Map<String, dynamic> json) {
    street1 = json["street1"];
    street2 = json["street2"];
    zip = json["zip"];
    city = json["city"];
    state = json["state"];
    country = json["country"];
    countryCode = json["countryCode"];
    informations = json["informations"];
    phone = json["phone"];
    phoneCode = json["phoneCode"];
    placeCatId = json["placeCatId"];
    oowoo = json["oowoo"];
    lng = json["lng"];
    lat = json["lat"];
    utcModifier = json["utcModifier"];
    frequentationDensity = json["frequentationDensity"];
    roadtype = json["roadtype"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["street1"] = street1;
    _data["street2"] = street2;
    _data["zip"] = zip;
    _data["city"] = city;
    _data["state"] = state;
    _data["country"] = country;
    _data["countryCode"] = countryCode;
    _data["informations"] = informations;
    _data["phone"] = phone;
    _data["phoneCode"] = phoneCode;
    _data["placeCatId"] = placeCatId;
    _data["oowoo"] = oowoo;
    _data["lng"] = lng;
    _data["lat"] = lat;
    _data["utcModifier"] = utcModifier;
    _data["frequentationDensity"] = frequentationDensity;
    _data["roadtype"] = roadtype;
    return _data;
  }

  OrderDeliveryAddress copyWith({
    String? street1,
    String? street2,
    String? zip,
    String? city,
    String? state,
    String? country,
    String? countryCode,
    String? informations,
    String? phone,
    String? phoneCode,
    int? placeCatId,
    int? oowoo,
    int? lng,
    int? lat,
    String? utcModifier,
    int? frequentationDensity,
    int? roadtype,
  }) =>
      OrderDeliveryAddress(
        street1: street1 ?? this.street1,
        street2: street2 ?? this.street2,
        zip: zip ?? this.zip,
        city: city ?? this.city,
        state: state ?? this.state,
        country: country ?? this.country,
        countryCode: countryCode ?? this.countryCode,
        informations: informations ?? this.informations,
        phone: phone ?? this.phone,
        phoneCode: phoneCode ?? this.phoneCode,
        placeCatId: placeCatId ?? this.placeCatId,
        oowoo: oowoo ?? this.oowoo,
        lng: lng ?? this.lng,
        lat: lat ?? this.lat,
        utcModifier: utcModifier ?? this.utcModifier,
        frequentationDensity: frequentationDensity ?? this.frequentationDensity,
        roadtype: roadtype ?? this.roadtype,
      );
}

class OrderItems {
  int? productRefId;
  int? price;
  String? currency;
  String? pricePeriod;
  String? label;
  String? subtitleLabel;
  String? description;

  OrderItems(
      {this.productRefId,
      this.price,
      this.currency,
      this.pricePeriod,
      this.label,
      this.subtitleLabel,
      this.description});

  OrderItems.fromJson(Map<String, dynamic> json) {
    productRefId = json["productRefId"];
    price = json["price"];
    currency = json["currency"];
    pricePeriod = json["pricePeriod"];
    label = json["label"];
    subtitleLabel = json["subtitleLabel"];
    description = json["description"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["productRefId"] = productRefId;
    _data["price"] = price;
    _data["currency"] = currency;
    _data["pricePeriod"] = pricePeriod;
    _data["label"] = label;
    _data["subtitleLabel"] = subtitleLabel;
    _data["description"] = description;
    return _data;
  }

  OrderItems copyWith({
    int? productRefId,
    int? price,
    String? currency,
    String? pricePeriod,
    String? label,
    String? subtitleLabel,
    String? description,
  }) =>
      OrderItems(
        productRefId: productRefId ?? this.productRefId,
        price: price ?? this.price,
        currency: currency ?? this.currency,
        pricePeriod: pricePeriod ?? this.pricePeriod,
        label: label ?? this.label,
        subtitleLabel: subtitleLabel ?? this.subtitleLabel,
        description: description ?? this.description,
      );
}

==> _private_core_network-1.1.5.tar.gz: lib/network_resources/model/payment_order.dart <==
class PaymentOrder {
  num? id;
  String? uuid;
  String? orderNumber;
  num? price;
  String? countryCode;
  num? createdAt;
  num? vat;
  String? proDisplayName;
  String? proUniqueId;
  String? userDisplayName;
  String? userUniqueId;
  String? paymentStatusLabel;
  num? deliveryAddressId;
  List<OrderItems>? items;
  OrderDeliveryAddress? deliveryAddress;

  PaymentOrder(
      {this.id,
      this.uuid,
      this.orderNumber,
      this.price,
      this.countryCode,
      this.createdAt,
      this.vat,
      this.proDisplayName,
      this.proUniqueId,
      this.userDisplayName,
      this.userUniqueId,
      this.paymentStatusLabel,
      this.deliveryAddressId,
      this.items,
      this.deliveryAddress});

  PaymentOrder.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    uuid = json["uuid"];
    orderNumber = json["orderNumber"];
    price = json["price"];
    countryCode = json["countryCode"];
    createdAt = json["createdAt"];
    vat = json["VAT"];
    proDisplayName = json["proDisplayName"];
    proUniqueId = json["proUniqueId"];
    userDisplayName = json["userDisplayName"];
    userUniqueId = json["userUniqueId"];
    paymentStatusLabel = json["paymentStatusLabel"];
    deliveryAddressId = json["deliveryAddressId"];
    items = json["items"] == null
        ? null
        : (json["items"] as List).map((e) => OrderItems.fromJson(e)).toList();
    deliveryAddress = json["deliveryAddress"] == null
        ? null
        : OrderDeliveryAddress.fromJson(json["deliveryAddress"]);
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["uuid"] = uuid;
    _data["orderNumber"] = orderNumber;
    _data["price"] = price;
    _data["countryCode"] = countryCode;
    _data["createdAt"] = createdAt;
    _data["VAT"] = vat;
    _data["proDisplayName"] = proDisplayName;
    _data["proUniqueId"] = proUniqueId;
    _data["userDisplayName"] = userDisplayName;
    _data["userUniqueId"] = userUniqueId;
    _data["paymentStatusLabel"] = paymentStatusLabel;
    _data["deliveryAddressId"] = deliveryAddressId;
    if (items != null) {
      _data["items"] = items?.map((e) => e.toJson()).toList();
    }
    if (deliveryAddress != null) {
      _data["deliveryAddress"] = deliveryAddress?.toJson();
    }
    return _data;
  }

  PaymentOrder copyWith({
    num? id,
    String? uuid,
    String? orderNumber,
    num? price,
    String? countryCode,
    num? createdAt,
    num? vat,
    String? proDisplayName,
    String? proUniqueId,
    String? userDisplayName,
    String? userUniqueId,
    String? paymentStatusLabel,
    num? deliveryAddressId,
    List<OrderItems>? items,
    OrderDeliveryAddress? deliveryAddress,
  }) =>
      PaymentOrder(
        id: id ?? this.id,
        uuid: uuid ?? this.uuid,
        orderNumber: orderNumber ?? this.orderNumber,
        price: price ?? this.price,
        countryCode: countryCode ?? this.countryCode,
        createdAt: createdAt ?? this.createdAt,
        vat: vat ?? this.vat,
        proDisplayName: proDisplayName ?? this.proDisplayName,
        proUniqueId: proUniqueId ?? this.proUniqueId,
        userDisplayName: userDisplayName ?? this.userDisplayName,
        userUniqueId: userUniqueId ?? this.userUniqueId,
        paymentStatusLabel: paymentStatusLabel ?? this.paymentStatusLabel,
        deliveryAddressId: deliveryAddressId ?? this.deliveryAddressId,
        items: items ?? this.items,
        deliveryAddress: deliveryAddress ?? this.deliveryAddress,
      );
}

class OrderDeliveryAddress {
  String? street1;
  String? street2;
  String? zip;
  String? city;
  String? state;
  String? country;
  String? countryCode;
  String? informations;
  String? phone;
  String? phoneCode;
  num? placeCatId;
  num? oowoo;
  num? lng;
  num? lat;
  String? utcModifier;
  num? frequentationDensity;
  num? roadtype;

  OrderDeliveryAddress(
      {this.street1,
      this.street2,
      this.zip,
      this.city,
      this.state,
      this.country,
      this.countryCode,
      this.informations,
      this.phone,
      this.phoneCode,
      this.placeCatId,
      this.oowoo,
      this.lng,
      this.lat,
      this.utcModifier,
      this.frequentationDensity,
      this.roadtype});

  OrderDeliveryAddress.fromJson(Map<String, dynamic> json) {
    street1 = json["street1"];
    street2 = json["street2"];
    zip = json["zip"];
    city = json["city"];
    state = json["state"];
    country = json["country"];
    countryCode = json["countryCode"];
    informations = json["informations"];
    phone = json["phone"];
    phoneCode = json["phoneCode"];
    placeCatId = json["placeCatId"];
    oowoo = json["oowoo"];
    lng = json["lng"];
    lat = json["lat"];
    utcModifier = json["utcModifier"];
    frequentationDensity = json["frequentationDensity"];
    roadtype = json["roadtype"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["street1"] = street1;
    _data["street2"] = street2;
    _data["zip"] = zip;
    _data["city"] = city;
    _data["state"] = state;
    _data["country"] = country;
    _data["countryCode"] = countryCode;
    _data["informations"] = informations;
    _data["phone"] = phone;
    _data["phoneCode"] = phoneCode;
    _data["placeCatId"] = placeCatId;
    _data["oowoo"] = oowoo;
    _data["lng"] = lng;
    _data["lat"] = lat;
    _data["utcModifier"] = utcModifier;
    _data["frequentationDensity"] = frequentationDensity;
    _data["roadtype"] = roadtype;
    return _data;
  }

  OrderDeliveryAddress copyWith({
    String? street1,
    String? street2,
    String? zip,
    String? city,
    String? state,
    String? country,
    String? countryCode,
    String? informations,
    String? phone,
    String? phoneCode,
    num? placeCatId,
    num? oowoo,
    num? lng,
    num? lat,
    String? utcModifier,
    num? frequentationDensity,
    num? roadtype,
  }) =>
      OrderDeliveryAddress(
        street1: street1 ?? this.street1,
        street2: street2 ?? this.street2,
        zip: zip ?? this.zip,
        city: city ?? this.city,
        state: state ?? this.state,
        country: country ?? this.country,
        countryCode: countryCode ?? this.countryCode,
        informations: informations ?? this.informations,
        phone: phone ?? this.phone,
        phoneCode: phoneCode ?? this.phoneCode,
        placeCatId: placeCatId ?? this.placeCatId,
        oowoo: oowoo ?? this.oowoo,
        lng: lng ?? this.lng,
        lat: lat ?? this.lat,
        utcModifier: utcModifier ?? this.utcModifier,
        frequentationDensity: frequentationDensity ?? this.frequentationDensity,
        roadtype: roadtype ?? this.roadtype,
      );
}

class OrderItems {
  num? productRefId;
  num? price;
  String? currency;
  String? pricePeriod;
  String? label;
  String? subtitleLabel;
  String? description;

  OrderItems(
      {this.productRefId,
      this.price,
      this.currency,
      this.pricePeriod,
      this.label,
      this.subtitleLabel,
      this.description});

  OrderItems.fromJson(Map<String, dynamic> json) {
    productRefId = json["productRefId"];
    price = json["price"];
    currency = json["currency"];
    pricePeriod = json["pricePeriod"];
    label = json["label"];
    subtitleLabel = json["subtitleLabel"];
    description = json["description"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["productRefId"] = productRefId;
    _data["price"] = price;
    _data["currency"] = currency;
    _data["pricePeriod"] = pricePeriod;
    _data["label"] = label;
    _data["subtitleLabel"] = subtitleLabel;
    _data["description"] = description;
    return _data;
  }

  OrderItems copyWith({
    num? productRefId,
    num? price,
    String? currency,
    String? pricePeriod,
    String? label,
    String? subtitleLabel,
    String? description,
  }) =>
      OrderItems(
        productRefId: productRefId ?? this.productRefId,
        price: price ?? this.price,
        currency: currency ?? this.currency,
        pricePeriod: pricePeriod ?? this.pricePeriod,
        label: label ?? this.label,
        subtitleLabel: subtitleLabel ?? this.subtitleLabel,
        description: description ?? this.description,
      );
}
